/*
 * OpenMobileIS - a free Java(TM) Framework for mobile applications Java(TM)
 * Copyright (C) 2004-2005 Philippe Delrieu
 * All rights reserved.
 * Contact: openmobileis@e-care.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  Author : Philippe Delrieu
 *  
 *  Modifications :
 *  2004 Creation P.Delrieu
 * 
 */

package org.openmobileis.embedded.util;

/**
 * Title:        OpenMobileIS project source <BR>
 * Description:  Generate an unique id for the PDA based  on the current time.
 * ID is not unique between several PDA. To have an unique id between PDA, use the PDAId
 * and the genrated id. 
 * The PDA id is egenrared by using the property pdaID in the file  PdaId.properties.
 * This property must be set manualy during installation or by using the synchronisation mecanism.
 * @author	Philippe Delrieu
 * @since	JDK 1.1
 * @version 1.0.
 */
public final class UniqueIdGenerator {
  
  private static UniqueIdGenerator manager;
  private String pdaId;
  private long currentId = 0;
  private int counter = 0;

  /** Creates a new instance of UniqueIdGenerator */
  public UniqueIdGenerator() {
  }
  public static UniqueIdGenerator getManager () {
    if (manager == null) {
      synchronized (UniqueIdGenerator.class) {
        if (manager == null)  {
          manager = new UniqueIdGenerator();
        }
      }
    }
    return manager;
  }

  // means representant Id
  public String getPdaId() {
    return pdaId;
  }

  public String getNextId () {
		return Long.toString(this.getLongNextId ());
  }

/*  public long getLongNextId () {
    long nextId = org.openmobileis.embedded.util.SystemAPI.currentTimeInMillis();
    if (nextId == this.currentId) {
       counter++;
       nextId = nextId + counter;
    } else {
      currentId = nextId;
      counter = 0;
    }
    return currentId;
  } */
  
  public long getLongNextId () {
	long nextId = org.openmobileis.embedded.util.SystemAPI.currentTimeInMillis();
	if (nextId <= this.currentId+counter) {
	   counter++;
	   nextId = nextId + counter;
	} else {
	  currentId = nextId;
	  counter = 0;
	}
	return nextId;
  }

}
