/*
 * OpenMobileIS - a free Java(TM) Framework for mobile applications Java(TM)
 * Copyright (C) 2004-2005 Philippe Delrieu
 * All rights reserved.
 * Contact: openmobileis@e-care.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  Author : Philippe Delrieu
 *  
 *  Modifications :
 *  2004 Creation P.Delrieu
 *  2004 Modified by Romain Beaugrand
 * 
 */

package org.openmobileis.embedded.webserver;

import org.openmobileis.common.util.ObjectPool;
import org.openmobileis.common.util.log.*;
import org.openmobileis.common.util.exception.ServerException;
import java.net.*;

import javax.servlet.ServletContext;

/**
 * Title:        OpenMobileIS project source <BR>
 * Description:  Runnable that handle connexion process in a thread.
 * @author	Philippe Delrieu
 * @since	JDK 1.1
 * @version 1.0.
 */
public class ServerThreadPool extends ObjectPool {
  class HTTPConnexionMaintener implements Runnable {
    public java.util.ArrayList connList;
    
    HTTPConnexionMaintener()  {
      connList = new java.util.ArrayList(5);
    }
    
    public void run() {
      while (true)  {
        try {
          Thread.currentThread().sleep(60000);       
        } catch (Throwable ex)  {
          LogManager.trace(new ServerException("Error in Thread that maintain ServletConnexion open", ex));          
        }
        long timeout = System.currentTimeMillis() - 60000;
        WebServerConnection conn = null;
        java.io.OutputStream stream = null;
        for (int i=0; i<connList.size(); i++)  {
          conn = (WebServerConnection)connList.get(i);
          if(conn.connexionLifeTime < timeout) { 
            try {
              stream = conn.getOutputStream();
              stream.write(' ');
            } catch (Throwable ex) {
              this.unregisterConnexion(conn);
            }
          }
        }
      }
    }
    
    public void registerConnexion(WebServerConnection connexion) {
      connList.add(connexion);
    }
    
    public void unregisterConnexion(WebServerConnection connexion) {
      connList.remove(connexion);
    }
    
  }
  
 // private HTTPConnexionMaintener maintener;

  public ServerThreadPool()  throws ClassNotFoundException, IllegalAccessException, InstantiationException  {
    super("org.openmobileis.embedded.webserver.ServerThread", 5, 5);
  //  maintener = new HTTPConnexionMaintener();
  }

  public synchronized void disposeObject(Object object) {
  //  maintener.unregisterConnexion(((ServerThread)object).getConnexion());
    super.disposeObject(object);
  }
  
  public void runServerConnexion(WebServer webserver, Socket socket) {
    ServerThread thread = (ServerThread) super.getObject();
    if (thread == null) {
      LogManager.traceEmergency(LogServices.SYNCHROSERVICE, "Object pool error ServerThread from pool NULL. Create one. System must be repared.");
      thread = new ServerThread();
    }

    try {
   //   maintener.registerConnexion(thread.getConnexion());
      thread.init(webserver, socket, this);
    } catch (Exception ex)  {
      LogManager.trace(new ServerException("Error during threadPool init", ex));
      LogManager.traceError(0, ex);
    }
  }
}
