/*
 * OpenMobileIS - a free Java(TM) Framework for mobile applications Java(TM)
 * Copyright (C) 2004-2005 Philippe Delrieu
 * All rights reserved.
 * Contact: openmobileis@e-care.fr
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  Author : Philippe Delrieu
 *  
 *  Modifications :
 *  2005 Creation P.Delrieu
 * 
 */

package org.openmobileis.modules.profils.embedded.data;

import com.microstar.xml.HandlerBase;
import org.openmobileis.common.util.collection.Array;

/**
 * Title:        OpenMobileIS project source <BR>
 * Description: Parse profil XML.
 * @author	Philippe Delrieu
 * @since	JDK 1.1
 * @version 1.0.
 */
public final class EmbeddedProfilChannelsParser extends HandlerBase {

  private EmbeddedProfilChannel currentChannel;
  private EmbeddedProfilRubric currentRubric;
  private int level = -1;
  private Array channels = new Array(5);
  private boolean takeSelectionAccount;
  String currentTag;
  private String currentPropValue = null;
  private String currentPropkey = null;

  public EmbeddedProfilChannelsParser(boolean takeSelectionAccount) {
    this.takeSelectionAccount = takeSelectionAccount;
  }

  public Array getChannels() {
    return channels;
  }

  /*** Parser methods  ***/
  public void startElement (String name) throws Exception  {
    if (name.equals("channel")) {
      currentChannel = new EmbeddedProfilChannel();
    } else if (name.equals("rubric")) {
      currentRubric = new EmbeddedProfilRubric();
    }
    currentTag = name;
  }

  public void endElement (String name) throws Exception {
    if (name.equals("channel")) {
      channels.add(currentChannel);
    } else if (name.equals("rubric")) {
      currentChannel.addRubic(currentRubric);
      currentRubric = null;
    } else if ( (name.equals("selected")) && (takeSelectionAccount)) {
      currentRubric.setSelection(true);
    } else if (name.equals("property")) {
      if((currentRubric!= null) && (currentPropkey != null) && (currentPropValue != null))  {
        currentRubric.addProperty(currentPropkey, currentPropValue);
      }
    }
  }

  public void charData(char ch[],
                      int start,
                      int length) throws Exception {
    String value = new String(ch, start, length);
    if ((ch[start] != '\n') &&(currentTag.equals("name"))) {
      if (currentRubric == null)
        currentChannel.setName(value);
      else
        currentRubric.setName(value);
    } else if ((ch[start] != '\n') &&(currentTag.equals("description"))) {
        currentRubric.setDescription(value);
    }
  }
  /**
    * Handle an attribute value assignment by printing an event.
    * @see com.microstar.xml.XmlHandler#attribute
    */
  public void attribute (String name, String value, boolean isSpecified)  {
    if (name.equals("key"))  {
      currentPropkey = value;
    } else if (name.equals("value")) {
      currentPropValue = value;
    }
  }

}